==> haskell-svg-builder-0.1.1-145-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-svg-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-61vlNf8zw5SES50QvslNly
key:                  svg-builder-0.1.1-61vlNf8zw5SES50QvslNly
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  c4c668caf319bf93763d26f352cf5741
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.0.2/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-61vlNf8zw5SES50QvslNly
depends:
    base-4.15.1.0 blaze-builder-0.4.2.2-2gLNFpRfQ1I6uT3J9lURjU
    bytestring-0.10.12.1 hashable-1.4.2.0-8JSq7I7AhyyZ2Q90BxZWW
    text-1.2.5.0 unordered-containers-0.2.19.1-Km0aDxhChoIJJSbiufyazz

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-svg-builder-0.1.1-147-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-svg-builder.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 svg-builder
version:              0.1.1
visibility:           public
id:                   svg-builder-0.1.1-CtjnQFcNXBYAetbZ8lN4l8
key:                  svg-builder-0.1.1-CtjnQFcNXBYAetbZ8lN4l8
license:              BSD-3-Clause
copyright:            2016 Jeffrey Rosenbluth
maintainer:           jeffrey.rosenbluth@gmail.com
author:               Jeffrey Rosenbluth
homepage:             https://github.com/diagrams/svg-builder.git
synopsis:             DSL for building SVG.
description:          Fast, easy to write SVG.
category:             Graphics
abi:                  084b35067138df99f23a58699c394b28
exposed:              True
exposed-modules:
    Graphics.Svg Graphics.Svg.Attributes Graphics.Svg.Core
    Graphics.Svg.Elements Graphics.Svg.Path

import-dirs:          /usr/lib/ghc-9.0.2/site-local/svg-builder-0.1.1
library-dirs:         /usr/lib/ghc-9.0.2/site-local/svg-builder-0.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-svg-builder
hs-libraries:         HSsvg-builder-0.1.1-CtjnQFcNXBYAetbZ8lN4l8
depends:
    base-4.15.1.0 blaze-builder-0.4.2.3-D7RNQqfFzoeIMP5JYaknz9
    bytestring-0.10.12.1 hashable-1.4.2.0-8EyZ5q0qf6V2oPuIX4Sz4t
    text-1.2.5.0 unordered-containers-0.2.19.1-4LWMSZiig8M6j2saT8CDNm

haddock-interfaces:   /usr/share/doc/haskell-svg-builder/html/svg-builder.haddock
haddock-html:         /usr/share/doc/haskell-svg-builder/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
